@@ -1,8 +1,4 @@
 from typing import Dict, Optional
-import os
-from rich.console import Console
-
-console = Console()
 
 from ciphey.iface import Checker, Config, ParamSpec, registry
 
@@ -15,9 +11,8 @@ class HumanChecker(Checker[str]):
 
     def check(self, text: str) -> Optional[str]:
         with self._config().pause_spinner_handle():
-            response = console.input(f"Result [blue bold]{text.__repr__()}[/blue bold] ([green]y[/green]/[red]N[/red]): ")
+            response = input(f"Result {text.__repr__()} (y/N): ").lower()
         if response == "y":
-            self.clear_terminal()
             return ""
         elif response in ("n", ""):
             return None
@@ -29,7 +24,3 @@ class HumanChecker(Checker[str]):
 
     def __init__(self, config: Config):
         super().__init__(config)
-
-    def clear_terminal(self):
-        # https://stackoverflow.com/a/2084628
-        os.system('cls' if os.name == 'nt' else 'clear')
